@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2017-2020, QIIME 2 development team.
+# Copyright (c) 2017-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -7,7 +7,7 @@
 # ----------------------------------------------------------------------------
 import os
 import pandas as pd
-import pandas.util.testing as pdt
+import pandas.testing as pdt
 import biom
 import shutil
 import json
@@ -113,7 +113,7 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
         self.mdc_ecam_fp = _load_nmc('ecam_map_maturity.txt', 'month')
         self.exp_imp = pd.read_csv(
             self.get_data_path('importance.tsv'), sep='\t', header=0,
-            index_col=0)
+            index_col=0, names=['feature', 'importance'])
         self.exp_pred = pd.read_csv(
             self.get_data_path('predictions.tsv'), sep='\t', header=0,
             index_col=0, squeeze=True)
@@ -152,7 +152,7 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             [1, 0, 4, 4],
             [4, 4, 0, 1],
             [4, 4, 1, 0],
-            ], ids=sample_ids)
+        ], ids=sample_ids)
 
         dm = qiime2.Artifact.import_data('DistanceMatrix', distance_matrix)
         categories = pd.Series(('skinny', 'skinny', 'fat', 'fat'),
@@ -182,7 +182,7 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             [2, 0, 1, 1],
             [3, 1, 0, 1],
             [3, 1, 1, 0],
-            ], ids=sample_ids)
+        ], ids=sample_ids)
 
         dm = qiime2.Artifact.import_data('DistanceMatrix', distance_matrix)
         categories = pd.Series(('fat', 'skinny', 'skinny', 'skinny'),
@@ -212,7 +212,7 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             [2, 0, 3, 4],
             [1, 3, 0, 3],
             [5, 4, 3, 0],
-            ], ids=sample_ids)
+        ], ids=sample_ids)
 
         dm = qiime2.Artifact.import_data('DistanceMatrix', distance_matrix)
         categories = pd.Series(('fat', 'skinny', 'skinny', 'skinny'),
@@ -251,6 +251,20 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
                 msg='Accuracy of %s classifier was %f, but expected %f' % (
                     classifier, accuracy, seeded_results[classifier]))
 
+    # test if training classifier with pipeline classify_samples raises
+    # warning when test_size = 0.0
+    def test_classify_samples_w_all_train_set(self):
+        with self.assertWarnsRegex(Warning, "not representative of "
+                                   "your model's performance"):
+            table_fp = self.get_data_path('chardonnay.table.qza')
+            table = qiime2.Artifact.load(table_fp)
+            sample_classifier.actions.classify_samples(
+                table=table, metadata=self.mdc_chard_fp,
+                test_size=0.0, cv=1, n_estimators=10, n_jobs=1,
+                estimator='RandomForestClassifier', random_state=123,
+                parameter_tuning=False, optimize_feature_selection=False,
+                missing_samples='ignore')
+
     # test that the plugin methods/visualizers work
     def test_regress_samples_ncv(self):
         y_pred, importances = regress_samples_ncv(
@@ -289,7 +303,8 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             name='prediction')
         exp_importances = pd.DataFrame(
             [0.595111111111111, 0.23155555555555551, 0.17333333333333334],
-            index=pd.Index(['o3', 'o1', 'o2']), columns=['importance'])
+            index=pd.Index(['o3', 'o1', 'o2'], name='feature'),
+            columns=['importance'])
         exp_probabilities = pd.DataFrame(
             [[0.5, 0.5], [0., 1.], [0., 1.], [0.5, 0.5], [0.5, 0.5],
              [0.5, 0.5], [0.5, 0.5], [0., 1.], [1., 0.], [1., 0.]],
@@ -390,28 +405,31 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             missing_samples='ignore')
 
     def test_split_table_no_rounding_error(self):
-        X_train, X_test = split_table(
+        X_train, X_test, y_train, y_test = split_table(
             self.table_chard_fp, self.mdc_chard_fp, test_size=0.5,
             random_state=123, stratify=True, missing_samples='ignore')
         self.assertEqual(len(X_train.ids()) + len(X_test.ids()), 21)
+        self.assertEqual(y_train.shape[0] + y_test.shape[0], 21)
 
     def test_split_table_no_split(self):
-        X_train, X_test = split_table(
+        X_train, X_test, y_train, y_test = split_table(
             self.table_chard_fp, self.mdc_chard_fp, test_size=0.0,
             random_state=123, stratify=True, missing_samples='ignore')
         self.assertEqual(len(X_train.ids()), 21)
+        self.assertEqual(y_train.shape[0], 21)
 
     def test_split_table_invalid_test_size(self):
         with self.assertRaisesRegex(ValueError, "at least two samples"):
-            X_train, X_test = split_table(
+            X_train, X_test, y_train, y_test = split_table(
                 self.table_chard_fp, self.mdc_chard_fp, test_size=1.0,
                 random_state=123, stratify=True, missing_samples='ignore')
 
     def test_split_table_percnorm(self):
-        X_train, X_test = split_table(
+        X_train, X_test, y_train, y_test = split_table(
             self.table_percnorm, self.mdc_percnorm, test_size=0.5,
             random_state=123, stratify=True, missing_samples='ignore')
         self.assertEqual(len(X_train.ids()) + len(X_test.ids()), 4)
+        self.assertEqual(y_train.shape[0] + y_test.shape[0], 4)
 
     # test experimental functions
     def test_detect_outliers(self):
@@ -450,6 +468,7 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
             sample_ids = pred.index.intersection(exp.index)
             pred = pred.loc[sample_ids]
             exp = exp.loc[sample_ids]
+            # verify predictions:
             # test that expected number of correct results is achieved (these
             # are mostly quite high as we would expect (total n=21))
             correct_results = np.sum(pred == exp)
@@ -458,6 +477,17 @@ class EstimatorsTests(SampleClassifierTestPluginBase):
                 msg='Accuracy of %s classifier was %f, but expected %f' % (
                     classifier, correct_results,
                     seeded_predict_results[classifier]))
+            # verify probabilities
+            # test whether all are in correct range (0 to 1)
+            ls_pred_classes = prob.columns.tolist()
+            ls_correct_range = [col for col in ls_pred_classes if
+                                prob[col].between(
+                                    0, 1, inclusive=True).all()]
+            self.assertEqual(len(ls_correct_range), prob.shape[1],
+                             msg='Predicted probabilities of class {}'
+                             'are not in range [0,1]'.format(
+                [col for col in ls_pred_classes
+                 if col not in ls_correct_range]))
 
     def test_predict_regressions(self):
         for regressor in ['RandomForestRegressor', 'ExtraTreesRegressor',
@@ -526,7 +556,7 @@ seeded_results = {
     'ExtraTreesClassifier': 0.454545454545,
     'GradientBoostingClassifier': 0.272727272727,
     'AdaBoostClassifier': 0.272727272727,
-    'LinearSVC': 0.727272727273,
+    'LinearSVC': 0.818182,
     'SVC': 0.36363636363636365,
     'KNeighborsClassifier': 0.363636363636,
     'RandomForestRegressor': 23.226508,
