@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2017-2020, QIIME 2 development team.
+# Copyright (c) 2017-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -18,7 +18,7 @@ from sklearn.ensemble import (RandomForestRegressor, RandomForestClassifier,
                               ExtraTreesClassifier, ExtraTreesRegressor,
                               AdaBoostClassifier, GradientBoostingClassifier,
                               AdaBoostRegressor, GradientBoostingRegressor)
-from sklearn.svm import LinearSVC, SVR, SVC
+from sklearn.svm import SVR, SVC
 from sklearn.linear_model import Ridge, Lasso, ElasticNet
 from sklearn.neighbors import KNeighborsClassifier, KNeighborsRegressor
 from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
@@ -47,20 +47,6 @@ parameters = {
                  "min_weight_fraction_leaf": [0.0001, 0.001, 0.01]},
     'bootstrap': {"bootstrap": [True, False]},
     'criterion': {"criterion": ["gini", "entropy"]},
-    'linear_svm': {"C": [1, 0.5, 0.1, 0.9, 0.8],
-                   # should probably include penalty in grid search, but:
-                   # Unsupported set of arguments: The combination of
-                   # penalty='l1' and loss='hinge' is not supported
-                   # "penalty": ["l1", "l2"],
-                   "loss": ["hinge", "squared_hinge"],
-                   "tol": [0.00001, 0.0001, 0.001]
-                   # should probably include this in grid search, as
-                   # dual=False is preferred when samples>features. However:
-                   # Unsupported set of arguments: The combination of
-                   # penalty='l2' and loss='hinge' are not supported when
-                   # dual=False
-                   # "dual": [True, False]
-                   },
     'svm': {"C": [1, 0.5, 0.1, 0.9, 0.8],
             "tol": [0.00001, 0.0001, 0.001, 0.01],
             "shrinking": [True, False]},
@@ -171,6 +157,9 @@ def _split_training_data(feature_data, targets, column, test_size=0.2,
         except ValueError:
             _stratification_error()
     else:
+        warning_msg = _warn_zero_test_split()
+        warnings.warn(warning_msg, UserWarning)
+
         X_train, X_test, y_train, y_test = (
             feature_data, feature_data, targets, targets)
 
@@ -438,11 +427,14 @@ def _predict_and_plot(output_dir, y_test, y_pred, vmin=None, vmax=None,
     else:
         predictions = _linear_regress(y_test, y_pred)
         predict_plot = _regplot_from_dataframe(y_test, y_pred)
+
     if output_dir is not None:
         predict_plot.get_figure().savefig(
             join(output_dir, 'predictions.png'), bbox_inches='tight')
         predict_plot.get_figure().savefig(
             join(output_dir, 'predictions.pdf'), bbox_inches='tight')
+
+    plt.close('all')
     return predictions, predict_plot
 
 
@@ -480,6 +472,14 @@ def _plot_accuracy(output_dir, predictions, truth, probabilities,
     or numeric data inside two pd.Series
     '''
     truth = truth.to_series()
+
+    # check if test_size == 0.0 and all predictions are complete dataset
+    if (missing_samples == 'ignore') & (
+            predictions.shape[0] == truth.shape[0]):
+        warning_msg = _warn_zero_test_split()
+    else:
+        warning_msg = None
+
     predictions, truth = _match_series_or_die(
         predictions, truth, missing_samples)
 
@@ -499,7 +499,7 @@ def _plot_accuracy(output_dir, predictions, truth, probabilities,
     # output to viz
     _visualize(output_dir=output_dir, estimator=None, cm=predictions,
                roc=probabilities, optimize_feature_selection=False,
-               title=plot_title)
+               title=plot_title, warning_msg=warning_msg)
 
 
 def sort_importances(importances, ascending=False):
@@ -523,6 +523,11 @@ def _summarize_estimator(output_dir, sample_estimator):
         rfep.savefig(join(output_dir, 'rfe_plot.pdf'))
         plt.close('all')
         optimize_feature_selection = True
+        # generate rfe scores file
+        df = pd.DataFrame(data={'rfe_score': sample_estimator.rfe_scores},
+                          index=sample_estimator.rfe_scores.index)
+        df.index.name = 'feature_count'
+        df.to_csv(join(output_dir, 'rfe_scores.tsv'), sep='\t', index=True)
     # if the rfe_scores attribute does not exist, do nothing
     except AttributeError:
         optimize_feature_selection = False
@@ -533,7 +538,8 @@ def _summarize_estimator(output_dir, sample_estimator):
 
 
 def _visualize(output_dir, estimator, cm, roc,
-               optimize_feature_selection=True, title='results'):
+               optimize_feature_selection=True, title='results',
+               warning_msg=None):
 
     pd.set_option('display.max_colwidth', None)
 
@@ -558,7 +564,8 @@ def _visualize(output_dir, estimator, cm, roc,
         'result': result,
         'predictions': cm,
         'roc': roc,
-        'optimize_feature_selection': optimize_feature_selection})
+        'optimize_feature_selection': optimize_feature_selection,
+        'warning_msg': warning_msg})
 
 
 def _visualize_knn(output_dir, params: pd.Series):
@@ -678,14 +685,11 @@ def predict_probabilities(estimator, test_set, index):
               have their class probabilities predicted.
     index: array-like of sample names
     '''
-    # most classifiers have a predict_proba attribute
-    try:
-        probs = pd.DataFrame(estimator.predict_proba(test_set),
-                             index=index, columns=estimator.classes_)
-    # SVMs use the decision_function attribute
-    except AttributeError:
-        probs = pd.DataFrame(estimator.decision_function(test_set),
-                             index=index, columns=estimator.classes_)
+    # all used classifiers have a predict_proba attribute
+    # (approximated for SVCs)
+    probs = pd.DataFrame(estimator.predict_proba(test_set),
+                         index=index, columns=estimator.classes_)
+
     return probs
 
 
@@ -763,11 +767,13 @@ def _select_estimator(estimator, n_jobs, n_estimators, random_state=None):
         estimator = GradientBoostingClassifier(
             n_estimators=n_estimators, random_state=random_state)
     elif estimator == 'LinearSVC':
-        param_dist = parameters['linear_svm']
-        estimator = LinearSVC(random_state=random_state)
+        param_dist = parameters['svm']
+        estimator = SVC(kernel='linear', random_state=random_state,
+                        gamma='scale', probability=True)
     elif estimator == 'SVC':
         param_dist = parameters['svm']
-        estimator = SVC(kernel='rbf', random_state=random_state, gamma='scale')
+        estimator = SVC(kernel='rbf', random_state=random_state,
+                        gamma='scale', probability=True)
     elif estimator == 'KNeighborsClassifier':
         param_dist = parameters['kneighbors']
         estimator = KNeighborsClassifier(algorithm='auto')
@@ -845,3 +851,11 @@ def _warn_feature_selection():
          'the parameter settings requested. See documentation or try a '
          'different estimator model.'))
     warnings.warn(warning, UserWarning)
+
+
+def _warn_zero_test_split():
+    return 'Using test_size = 0.0, you are using your complete dataset for ' \
+        'fitting the estimator. Hence, any returned model evaluations are ' \
+        'based on that same training dataset and are not representative of ' \
+        'your model\'s performance on a previously unseen dataset. Please ' \
+        'consider evaluating this model on a separate dataset.'
